@@ -934,7 +934,7 @@ def _merge_with(obj, *sources, **kwargs):
             if _result is not None:
                 result = _result
             elif all_sequences or all_mappings:
-                result = _merge_with(obj_value, src_value, _setter=setter)
+                result = _merge_with(obj_value, src_value, iteratee=iteratee, _setter=setter)
             else:
                 result = src_value
 
@@ -1051,7 +1051,7 @@ def parse_int(value, radix=None):
     """
     if not radix and pyd.is_string(value):
         try:
-            # Check if value is hexadcimal and if so use base-16 conversion.
+            # Check if value is hexadecimal and if so use base-16 conversion.
             int(value, 16)
         except ValueError:
             pass
